@@ -16,13 +16,31 @@ class Tag(models.Model):
             self.url_key = slugify(self.name)
         return super(Tag, self).save()
 
+class Gallery(models.Model):
+    name = models.CharField(max_length=128)
+
+    def __unicode__(self):
+        return u"%s" % self.name
+
+class Image(models.Model):
+    gallery = models.ForeignKey(Gallery)
+    img = models.ImageField(upload_to="imgs")
+
+    name = models.CharField(max_length=128, null=True, blank=True)
+    description = models.TextField(null=True, blank=True)
+
+    def __unicode__(self):
+        return u"%s ~%i" % (self.gallery.name, self.pk)
+
 class Article(models.Model):
     title = models.CharField(max_length=128)
     url_key = models.SlugField(max_length=128, blank=True)
     created_at = models.DateField(auto_now_add=True)
-    tags = models.ManyToManyField(Tag)
+    tags = models.ManyToManyField(Tag, null=True, blank=True)
     img = models.ImageField(null=True, blank=True, upload_to="img")
+    gallery = models.ManyToManyField(Gallery, blank=True)
     description = models.TextField()
+    line_breaks_br = models.BooleanField()
     content = models.TextField()
 
     def __unicode__(self):
@@ -57,4 +75,4 @@ class Link(models.Model):
     size = models.IntegerField(default=18)
 
     def __unicode__(self):
-        return u"%s %s" % (self.name, self.url)
\ No newline at end of file
+        return u"%s %s" % (self.name, self.url)
