@@ -20,6 +20,11 @@ url(r'^a/(?P<url_key>[a-zA-Z0-9-/]+)/$',
      article_view,
      name="simpleblog.article", ),
 
+url(r'^js/lightbox.js$',
+     direct_to_template,
+     {"template": "simpleblog/lightbox/lightbox.js", "mimetype": "text/javascript"},
+     name="simpleblog.js.lightbox", ),
+
 # url(r"^knihy/$",
 #     book_list_view,
 #     name="prodejknihu.book_list", ),
